<?php
/**
 * @version     1.0.0
 * @package     Default Article Picture
 * @author      Mircea Rusu - http://unicserv.ro
 * @copyright   Copyright (c) 2022 - currentyear. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 */

// no direct access
defined( '_JEXEC' ) or die( 'Restricted access' );

use Joomla\Registry\Registry;
use Joomla\CMS\Plugin\CMSPlugin as JPlugin;
use Joomla\CMS\Categories\Categories as JCategories;

/**
 * U Default Picture Plugin
 *
 */
class PlgContentUDefaultPicture extends JPlugin
{

	protected $db;
	protected $_version = '2.0.15';
    protected $_basepath = '/plugins/content/udefaultpicture/';

    function __construct(&$subject, $params)
    {
        parent::__construct($subject, $params);
    }

	/**
	 * Plugin that use the category or the global declared pictures as the article pictures when 
	 * there is no picture defined in article's intro or article's full page
	 *
	 * The plugin will write the chosen picture urls in the database at onContentBeforeSave Joomla! event 
	 * ONLY when there is no picture already defined by the user.
	 *
	 * @param   string   $context  The context of the content being passed to the plugin.
	 * @param   mixed    &$row     An object with a "text" property
	 * @param   mixed    $params   Additional parameters. See {@see PlgContentContent()}.
	 * @param   integer  $page     Optional page number. Unused. Defaults to zero.
	 *
	 * @return  boolean	True on success.
	 */
	public function onContentBeforeSave($context, &$article, &$params, $page = 0)
	{
		$allowed_contexts = array('com_content.category', 'com_content.article', 'com_content.featured');

		if (!in_array($context, $allowed_contexts))
		{
			return true;
		}
		//get plugin params
	$plugin = JPluginHelper::getPlugin('content', 'udefaultpicture');
	$pluginParams = json_decode($plugin->params);
	
		//get article images	
	$images = json_decode($article->images);
		
	switch ($pluginParams->default_functionality) {
		case "globalimg":
			$replacementImage = $pluginParams->global_image_default;
			break;
		case 'categoryimg':
			// get the category image	
			$category = JCategories::getInstance('Content')->get($article->catid);
			if(!$category){
				return true;
			}
			$registry = new Registry();
			$catVars=$registry->loadstring($category->params,'JSON')->toArray();
			$replacementImage = $catVars['image'];	
			break;
		case 'categoryoverrideglobal':
			// get the category image	
			$category = JCategories::getInstance('Content')->get($article->catid);
			if(!$category){
				return true;
			}
			$registry = new Registry();
			$catVars=$registry->loadstring($category->params,'JSON')->toArray();
			if (empty($catVars['image'])) {
				$replacementImage = $pluginParams->global_image_default;
			}
			else {
				$replacementImage = $catVars['image'];
			}
			break;	
	}
		// get all categories images in order to identify if the previous image was a category image meaning that the category may be changed

			$db = JFactory::getDbo();
			$query = $db->getQuery(true);
			$query->select($db->quoteName(array('params')));
			$query->from($db->quoteName('#__categories'));
			$query->where($db->quoteName('extension') . ' LIKE ' . $db->quote('com_content'));
			$db->setQuery($query);
			// Load the catImagesList as a column array.
			$catImagesList = $db->loadObjectList();
			//Check if the previous article's images whas a category image. 
			//This is used in case of category change since the article's images has to be updated with the current category image.
			$introImageIsACategoryImage = false;
			$fulltextImageIsACategoryImage = false;
			foreach ($catImagesList as $catImageJson) {
				$catImage = json_decode($catImageJson->params)->image;
				if (!empty($images->image_intro) && ($images->image_intro == $catImage)) {
					$introImageIsACategoryImage = true;
				}
				if (!empty($images->image_fulltext) && ($images->image_fulltext == $catImage)) {
					$fulltextImageIsACategoryImage = true;
				}
			}
			unset($catImageJson);
		
		//insert default image if the article images are empty or the previous article's images where a category image;
		if (isset($images->image_intro) && ($introImageIsACategoryImage || empty($images->image_intro)) && ($pluginParams->images_to_change <> "full_image_only")) {
			$images->image_intro = $replacementImage;
		}
		
		if (isset($images->image_fulltext) && ($fulltextImageIsACategoryImage || empty($images->image_fulltext)) && ($pluginParams->images_to_change <> "intro_image_only")) {
			$images->image_fulltext = $replacementImage;
		}
		$article->images = json_encode($images);	
		return true;
	}
}
